# NAME

pytrisk - a classical Risk boardgame in python


# DESCRIPTION

Risk is a strategic turn-based board game. Players control armies, with
which they attempt to capture territories from other players. The goal
of the game is to control all the territories ("conquer the world")
through the elimination of the other players. Using area movement, Risk
ignores realistic limitations, such as the vast size of the world, and
the logistics of long campaigns.

This distribution implements a graphical interface for this game, with
everything needed to play (including artificial intelligence opponents).


# INSTALL AND USAGE

Just install via pip:

    pip install pytrisk

Once installed, launch the game either via the pytrisk script:

    pytrisk

or by loading the pytrisk module:

    python -m pytrisk


# SUPPORT

The homepage for this program is https://github.com/jquelin/pytrisk,
where you will be able to find the source code and a bug tracker.


# AUTHOR

Jérôme Quelin <jquelin@gmail.com>


# COPYRIGHT AND LICENCE

This software is copyright (c) 2022 by Jerome Quelin.

This is free software; you can redistribute it and/or modify it under
the terms of the GNU GPLv3 license - see LICENSE and COPYING files.
